@@ -65,7 +65,7 @@
 /* Buffers received packets of type APPLICATION DATA,
  * HANDSHAKE DATA and HEARTBEAT.
  */
-int
+void
 _gnutls_record_buffer_put(gnutls_session_t session,
 			  content_type_t type, uint64 * seq,
 			  mbuffer_st * bufel)
@@ -78,7 +78,7 @@ _gnutls_record_buffer_put(gnutls_session_t session,
 	_gnutls_buffers_log("BUF[REC]: Inserted %d bytes of Data(%d)\n",
 			    (int) bufel->msg.size, (int) type);
 
-	return 0;
+	return;
 }
 
 /**
@@ -88,7 +88,7 @@ _gnutls_record_buffer_put(gnutls_session_t session,
  * This function checks if there are unread data
  * in the gnutls buffers. If the return value is
  * non-zero the next call to gnutls_record_recv()
- * is guarranteed not to block.
+ * is guaranteed not to block.
  *
  * Returns: Returns the size of the data or zero.
  **/
@@ -97,6 +97,22 @@ size_t gnutls_record_check_pending(gnutls_session_t session)
 	return _gnutls_record_buffer_get_size(session);
 }
 
+/**
+ * gnutls_record_check_corked:
+ * @session: is a #gnutls_session_t structure.
+ *
+ * This function checks if there pending corked
+ * data in the gnutls buffers --see gnutls_cork(). 
+ *
+ * Returns: Returns the size of the corked data or zero.
+ *
+ * Since: 3.2.8
+ **/
+size_t gnutls_record_check_corked(gnutls_session_t session)
+{
+	return session->internals.record_presend_buffer.length;
+}
+
 int
 _gnutls_record_buffer_get(content_type_t type,
 			  gnutls_session_t session, uint8_t * data,
@@ -650,13 +666,15 @@ ssize_t _gnutls_io_write_flush(gnutls_session_t session)
  */
 int _gnutls_io_check_recv(gnutls_session_t session, unsigned int ms)
 {
-	gnutls_transport_ptr_t fd = session->internals.transport_send_ptr;
+	gnutls_transport_ptr_t fd = session->internals.transport_recv_ptr;
 	int ret = 0, err;
 
 	if (unlikely
 	    (session->internals.pull_timeout_func == system_recv_timeout
-	     && session->internals.pull_func != system_read))
+	     && session->internals.pull_func != system_read)) {
+		_gnutls_debug_log("The pull function has been replaced but not the pull timeout.");
 		return gnutls_assert_val(GNUTLS_E_PULL_ERROR);
+	}
 
 	reset_errno(session);
 
@@ -906,7 +924,7 @@ static int merge_handshake_packet(gnutls_session_t session,
 	if (exists == 0)
 		pos = session->internals.handshake_recv_buffer_size;
 
-	if (pos > MAX_HANDSHAKE_MSGS)
+	if (pos >= MAX_HANDSHAKE_MSGS)
 		return
 		    gnutls_assert_val(GNUTLS_E_TOO_MANY_HANDSHAKE_PACKETS);
 
